@@ -70,6 +70,9 @@ class bigjob_agent:
         # conf_file = os.path.dirname(args[0]) + "/" + CONFIG_FILE
         # conf_file = os.path.dirname(os.path.abspath( __file__ )) + "/" + CONFIG_FILE
         conf_file = os.path.dirname(os.path.abspath( __file__ )) + "/../" + CONFIG_FILE
+        if not os.path.exists(conf_file):
+            _conf_file = os.path.join(sys.prefix, CONFIG_FILE)
+        
         config = ConfigParser.ConfigParser()
         logging.debug ("read configfile: " + conf_file)
         config.read(conf_file)
