@@ -8,6 +8,7 @@ import sys
 import os
 import pickle
 import pdb
+import time
 
 from bigjob import logger
 sys.path.insert(0, (os.path.dirname(os.path.abspath( __file__) ) + "/../ext/redis-2.4.9/"))
@@ -44,6 +45,7 @@ class bigjob_coordination(object):
         self.password = None   
         
         self.address = "%s%s:%i"%(REDIS_URL_SCHEME, server, server_port)
+        self.dbtype=""
         if server_connect_url!=None:
             self.address=server_connect_url    
             start_index = self.address.find(REDIS_URL_SCHEME)+len(REDIS_URL_SCHEME)
@@ -74,7 +76,7 @@ class bigjob_coordination(object):
         else:
             self.redis = Redis(host=server, port=server_port, password=self.password, db=0)
         #self.redis_pubsub = self.redis.pubsub() # redis pubsub client       
-        self.resource_lock = threading.RLock()
+        #self.resource_lock = threading.RLock()
         self.pipe = self.redis.pipeline()
         try:
             self.redis.ping()
@@ -110,7 +112,6 @@ class bigjob_coordination(object):
         description = self.redis.hgetall(pilot_url + ":description")
         return description
     
-    
     #def is_pilot_stopped(self,pilot_url):
     #    state = self.redis.hgetall(pilot_url)
     #    if state==None or not state.has_key("stopped"):
@@ -119,7 +120,10 @@ class bigjob_coordination(object):
     
     def get_jobs_of_pilot(self, pilot_url):
         """ returns array of job_url that are associated with a pilot """
-        return self.redis.keys(pilot_url+":jobs:*") 
+        jobs = self.redis.keys(pilot_url+":jobs:*")
+        jobs_fqdn = [os.path.join(self.get_address(), i)for i in jobs] 
+        return jobs_fqdn
+    
     
     def delete_pilot(self, pilot_url):
         items = self.redis.keys(pilot_url+"*")  
@@ -133,6 +137,15 @@ class bigjob_coordination(object):
         #self.resource_lock.acquire()        
         logger.debug("set job state to: " + str(new_state))
         self.redis.hset(job_url, "state", str(new_state))
+        
+        if new_state=="Unknown":
+            self.redis.hset(job_url,"start_time", str(time.time()))
+        elif new_state=="Running":
+            self.redis.hset(job_url,"end_queue_time", str(time.time()))
+        elif new_state=="Done":
+            self.redis.hset(job_url, "end_time", str(time.time()))
+       
+        
         #self.resource_lock.release()
         
     def get_job_state(self, job_url):
@@ -143,7 +156,8 @@ class bigjob_coordination(object):
     # Sub-Job Description
     def set_job(self, job_url, job_dict):
         self.redis.hmset(job_url, job_dict)
-    
+        self.set_job_state(job_url, "Unknown")
+        
     def get_job(self, job_url):
         return self.redis.hgetall(job_url)    
     
@@ -166,7 +180,7 @@ class bigjob_coordination(object):
         logger.debug("Dequeue sub-job from: " + queue_name 
                       + " number queued items: " + str(self.redis.llen(queue_name)))
         self.redis.set(queue_name + ':last_out', pickle.dumps(datetime.datetime.now()))
-        job_url = self.redis.brpop(queue_name, 120)
+        job_url = self.redis.brpop(queue_name, 1)
         if job_url==None:
             return job_url
         logger.debug("Dequeued: " + str(job_url))
